@@ -12,8 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
-
 from fuelclient.cli import error
 from fuelclient import objects
 from fuelclient.v1 import base_v1
@@ -23,25 +21,18 @@ class EnvironmentClient(base_v1.BaseV1Client):
 
     _entity_wrapper = objects.Environment
 
-    _updatable_attributes = ('name', 'mode')
+    _updatable_attributes = ('name',)
 
-    def create(self, name, release_id, network_provider,
-               deployment_mode='ha_compact', net_segment_type=None):
+    def create(self, name, release_id, net_segment_type):
 
-        if network_provider == 'neutron':
-            if net_segment_type not in ('gre', 'vlan', 'tun'):
-                msg = 'Using  Neutron as a network provider requires '\
-                      'specifying network segmentation type.'
-                raise error.BadDataException(msg)
-        else:
-            if net_segment_type:
-                msg = 'Network segmentation type should only be '\
-                      'specified for Neutron.'
-                raise error.BadDataException(msg)
+        supported_nst = ('gre', 'vlan', 'tun')
 
-        env = self._entity_wrapper.create(name, release_id, network_provider,
-                                          net_segment_type,
-                                          mode=deployment_mode)
+        if net_segment_type not in supported_nst:
+            msg = ('Network segmentation type should be one '
+                   'of  {0}'.format(' '.join(supported_nst)))
+            raise error.BadDataException(msg)
+
+        env = self._entity_wrapper.create(name, release_id, net_segment_type)
 
         return env.data
 
@@ -49,7 +40,7 @@ class EnvironmentClient(base_v1.BaseV1Client):
         allowed_changes = {}
         extra_args = {}
 
-        for i in six.iterkeys(kwargs):
+        for i in kwargs:
             if i in self._updatable_attributes:
                 allowed_changes[i] = kwargs[i]
             else:
